Discussion
==========

.. <!--alex ignore black-->

.. toctree::
   :maxdepth: 1

   structure/index.rst
   pytest/index.rst
   tox/index.rst
   flit/index.rst
   virtualenv/index.rst
   coverage/index.rst
   hypothesis/index.rst
   black/index.rst
   flake8/index.rst
   interrogate/index.rst
   darglint/index.rst
   mypy/index.rst
   sphinx/index.rst
   doctests/index.rst
   alex/index.rst
   github_actions/index.rst
   readthedocs/index.rst
   mdformat/index.rst
